@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 import abc
-import hashlib
 import json
-from xml.dom.minidom import parseString
-from xml.etree.ElementTree import Element, SubElement, tostring
 
 from Tea.exceptions import TeaException, UnretryableException
-
 from alibabacloud_dkms_transfer.utils.consts import *
 from alibabacloud_dkms_transfer.utils.kms_error_code_transfer_utils import *
 
@@ -45,39 +41,10 @@ def transfer_tea_exception(e):
         return status_code, ServerException(e.code, error_message, request_id=request_id, http_status=status_code)
 
 
-def transfer_tea_unretryable_exception(e):
-    if isinstance(e, UnretryableException):
-        if "Read timed out" in e.message or "timeout" in e.message or isinstance(e.inner_exception, IOError):
-            return ClientException(code="SDK.ReadTimeout", msg="%s" % str(e))
-        elif "Name or service not known" in e.message:
-            return ClientException(code="SDK.ServerUnreachable", msg="%s" % str(e))
-    return ClientException("", str(e))
-
-
-def dict_to_body(dic, accept_format, tag):
-    if accept_format is not None and accept_format.upper() == "XML":
-        xml_str = parseString(tostring(dict_to_xml(dic, Element(tag), tag))).toprettyxml()
-        if xml_str.startswith('<?xml version="1.0" ?>\n'):
-            xml_str = xml_str[23:]
-        return xml_str.encode("utf-8")
+def dict_to_body(dic):
     return json.dumps(dic, indent=4, ensure_ascii=False).encode("utf-8")
 
 
-def dict_to_xml(dic, elem, tag):
-    if isinstance(dic, dict):
-        for key in dic:
-            if isinstance(dic[key], list):
-                dict_to_xml(dic[key], elem, key)
-            else:
-                elem.append(dict_to_xml(dic[key], Element(key), key))
-    elif isinstance(dic, list):
-        for val in dic:
-            SubElement(elem, tag).text = str(val)
-    else:
-        elem.text = str(dic)
-    return elem
-
-
 class KmsTransferHandler(object):
     __metaclass__ = abc.ABCMeta
 
@@ -97,12 +64,12 @@ class KmsTransferHandler(object):
             if isinstance(e.inner_exception, TeaException):
                 status, exception = transfer_tea_exception(e.inner_exception)
                 body = {"HttpStatus": status, "Code": exception.error_code, "Message": exception.message}
-                return status, None, dict_to_body(body, request.get_accept_format(), "KMS"), exception
-            raise transfer_tea_unretryable_exception(e)
+                return status, None, dict_to_body(body), exception
+            raise ClientException("", e.message)
         except TeaException as e:
             status, exception = transfer_tea_exception(e)
             body = {"HttpStatus": status, "Code": exception.error_code, "Message": exception.message}
-            return status, None, dict_to_body(body, request.get_accept_format(), "KMS"), exception
+            return status, None, dict_to_body(body), exception
         except ClientException as e:
             raise e
         except Exception as e:
@@ -119,21 +86,3 @@ class KmsTransferHandler(object):
     @abc.abstractmethod
     def call_dkms(self, dkms_request, runtime_options):
         pass
-
-
-def encode_user_encryption_context(context: str) -> bytes:
-    context_dict = json.loads(context)
-    keys = []
-    for k, v in context_dict.items():
-        if v is not None:
-            keys.append(k)
-    keys.sort()
-    context_string = ''
-    keys_len = len(keys)
-    for i, key in enumerate(keys):
-        context_string += key + '=' + context_dict[key]
-        if i < keys_len - 1:
-            context_string += '&'
-    sha_256 = hashlib.sha256()
-    sha_256.update(context_string.encode(encoding='utf-8'))
-    return sha_256.digest()
